@@ -1,6 +1,6 @@
 package Pithub::Gists;
-{
-  $Pithub::Gists::VERSION = '0.01008';
+BEGIN {
+  $Pithub::Gists::VERSION = '0.01009';
 }
 
 # ABSTRACT: Github v3 Gists API
@@ -146,7 +146,7 @@ Pithub::Gists - Github v3 Gists API
 
 =head1 VERSION
 
-version 0.01008
+version 0.01009
 
 =head1 METHODS
 
@@ -204,7 +204,7 @@ Examples:
         printf "The new gist is available at %s\n", $result->content->{html_url};
     }
 
-Response: C<< Status: 201 Created >>
+Response: B<Status: 201 Created>
 
     {
         "url": "https://api.github.com/gists/1",
@@ -291,7 +291,7 @@ Examples:
         print "The gist 784612 has been deleted\n";
     }
 
-Response: C<< Status: 204 No Content >>
+Response: B<Status: 204 No Content>
 
 =back
 
@@ -323,7 +323,7 @@ Examples:
         printf "The gist 784612 has been forked: %s\n", $result->content->{html_url};
     }
 
-Response: C<< Status: 201 Created >>
+Response: B<Status: 201 Created>
 
     {
         "url": "https://api.github.com/gists/1",
@@ -380,7 +380,7 @@ Examples:
         print $result->content->{html_url};
     }
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     {
         "url": "https://api.github.com/gists/1",
@@ -464,7 +464,7 @@ Examples:
     my $g = Pithub::Gists->new;
     my $result = $g->is_starred( gist_id => 784612 );
 
-Response: C<< Status: 204 No Content >> / C<< Status: 404 Not Found >>
+Response: B<Status: 204 No Content> / C<< Status: 404 Not Found >>
 
 =back
 
@@ -552,7 +552,7 @@ Examples:
     my $g = Pithub::Gists->new;
     my $result = $g->list( starred => 1 );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     [
         {
@@ -608,7 +608,7 @@ Examples:
     my $g = Pithub::Gists->new;
     my $result = $g->star( gist_id => 784612 );
 
-Response: C<< Status: 204 No Content >>
+Response: B<Status: 204 No Content>
 
 =back
 
@@ -637,7 +637,7 @@ Examples:
     my $g = Pithub::Gists->new;
     my $result = $g->unstar( gist_id => 784612 );
 
-Response: C<< Status: 204 No Content >>
+Response: B<Status: 204 No Content>
 
 =back
 
@@ -704,7 +704,7 @@ Examples:
         }
     );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     {
         "url": "https://api.github.com/gists/1",
