@@ -1,6 +1,6 @@
 package Pithub::Gists::Comments;
-{
-  $Pithub::Gists::Comments::VERSION = '0.01008';
+BEGIN {
+  $Pithub::Gists::Comments::VERSION = '0.01009';
 }
 
 # ABSTRACT: Github v3 Gist Comments API
@@ -77,7 +77,7 @@ Pithub::Gists::Comments - Github v3 Gist Comments API
 
 =head1 VERSION
 
-version 0.01008
+version 0.01009
 
 =head1 METHODS
 
@@ -121,7 +121,7 @@ Examples:
         data    => { body => 'Just commenting for the sake of commenting' },
     );
 
-Response: C<< Status: 201 Created >>
+Response: B<Status: 201 Created>
 
     {
         "id": 1,
@@ -163,7 +163,7 @@ Examples:
     my $c = Pithub::Gists::Comments->new;
     my $result = $c->delete( comment_id => 1 );
 
-Response: C<< Status: 204 No Content >>
+Response: B<Status: 204 No Content>
 
 =back
 
@@ -192,7 +192,7 @@ Examples:
     my $c = Pithub::Gists::Comments->new;
     my $result = $c->get( comment_id => 1 );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     {
         "id": 1,
@@ -234,7 +234,7 @@ Examples:
     my $c = Pithub::Gists::Comments->new;
     my $result = $c->list( gist_id => 1 );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     [
         {
@@ -293,7 +293,7 @@ Examples:
         data       => { body => 'some comment' }
     );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     {
         "id": 1,
