@@ -1,6 +1,6 @@
 package Pithub::GitData::Blobs;
-{
-  $Pithub::GitData::Blobs::VERSION = '0.01008';
+BEGIN {
+  $Pithub::GitData::Blobs::VERSION = '0.01009';
 }
 
 # ABSTRACT: Github v3 Git Data Blobs API
@@ -44,7 +44,7 @@ Pithub::GitData::Blobs - Github v3 Git Data Blobs API
 
 =head1 VERSION
 
-version 0.01008
+version 0.01009
 
 =head1 DESCRIPTION
 
@@ -107,7 +107,7 @@ Examples:
         }
     );
 
-Response: C<< Status: 201 Created >>
+Response: B<Status: 201 Created>
 
     {
         "sha": "3a0f86fb8db8eea7ccbb9a95f325ddbedfb25e15"
@@ -152,7 +152,7 @@ Examples:
         sha  => 'b7cdea6830e128bc16c2b75efd99842d971666e2',
     );
 
-Response: C<< Status: 200 OK >>
+Response: B<Status: 200 OK>
 
     {
         "content": "Content of the blob",
